==> ruby18-asp-0.3.3.tbz: lib/ruby/site_ruby/1.8/asp/asperror.rb <==
# Copyright (C) 2003, 2004 Gregoire Lejeune <gregoire.lejeune@free.fr>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA

module Asp
  class Error
    public
    attr_accessor(
      :aspCode,
      :aspDescription,
      :category,
      :column,
      :file,
      :line,
      :number,
      :source
    )

    private
    def initialize
      @aspCode        # retourne un code d'erreur gnr par apache (IIS !!!)
      @aspDescription # retourne une description dtaille de l'errreur s'il s'agt d'une erreur relative  ASP.
      @category       # indique si la source de l'erreur tait interne  ASP, au langage de script, ou  un objet.
      @column         # indique un numro de colonne  l'intrieur d'un fichier ASP a gnr l'erreur.
      @file           # indique le nom du fichier portant l'extension .asp qui tait trait lorsqu'une erreur s'est produite.
      @line           # indique un numro de ligne  l'intrieur d'un fichier ASP qui a gnr l'erreur.
      @number         # retourne le numro de l'erreur COM standard !!!
      @source         # retourne le code source responsable de l'erreur.
    end
  end
end

==> ruby18-asp-0.4.1_1.tbz: lib/ruby/site_ruby/1.8/asp/asperror.rb <==
# Copyright (C) 2003, 2004 Gregoire Lejeune <gregoire.lejeune@free.fr>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA

module Asp
  class Error
    public
    attr_accessor(
      :aspCode,
      :aspDescription,
      :category,
      :column,
      :file,
      :line,
      :number,
      :source
    )

    private
    def initialize
      @aspCode        # retourne un code d'erreur gnr par apache (IIS !!!)
      @aspDescription # retourne une description dtaille de l'erreur s'il s'agt d'une erreur relative  ASP.
      @category       # indique si la source de l'erreur tait interne  ASP, au langage de script, ou  un objet.
      @column         # indique un numro de colonne  l'intrieur d'un fichier ASP a gnr l'erreur.
      @file           # indique le nom du fichier portant l'extension .asp qui tait trait lorsqu'une erreur s'est produite.
      @line           # indique un numro de ligne  l'intrieur d'un fichier ASP qui a gnr l'erreur.
      @number         # retourne le numro de l'erreur COM standard !!!
      @source         # retourne le code source responsable de l'erreur.
    end
  end
end
